@@ -4,7 +4,7 @@ local({
     function() {
         if(is.null(.providers)) {
             providers <-
-                html_tables("http://www.openarchives.org/Register/BrowseSites")
+                html_tables("https://www.openarchives.org/Register/BrowseSites")
             providers <- providers[[1L]][, 3L : 5L]
             names(providers) <- c("name", "baseurl", "identifier")
             .providers <<- providers
